@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -35,6 +35,7 @@ from google.cloud.osconfig_v1.services.os_config_service import pagers
 from google.cloud.osconfig_v1.types import patch_deployments
 from google.cloud.osconfig_v1.types import patch_jobs
 from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import OsConfigServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import OsConfigServiceGrpcAsyncIOTransport
@@ -119,6 +120,42 @@ class OsConfigServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return OsConfigServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> OsConfigServiceTransport:
         """Returns the transport used by the client instance.
@@ -190,6 +227,26 @@ class OsConfigServiceAsyncClient:
         r"""Patch VM instances by creating and running a patch
         job.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_execute_patch_job():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ExecutePatchJobRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.execute_patch_job(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ExecutePatchJobRequest, dict]):
                 The request object. A request message to initiate
@@ -250,6 +307,26 @@ class OsConfigServiceAsyncClient:
         progress of an ongoing patch job or review the details
         of completed jobs.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_patch_job():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetPatchJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_patch_job(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetPatchJobRequest, dict]):
                 The request object. Request to get an active or
@@ -282,7 +359,7 @@ class OsConfigServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -329,6 +406,26 @@ class OsConfigServiceAsyncClient:
         r"""Cancel a patch job. The patch job must be active.
         Canceled patch jobs cannot be restarted.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_cancel_patch_job():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.CancelPatchJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.cancel_patch_job(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.CancelPatchJobRequest, dict]):
                 The request object. Message for canceling a patch job.
@@ -386,6 +483,24 @@ class OsConfigServiceAsyncClient:
     ) -> pagers.ListPatchJobsAsyncPager:
         r"""Get a list of patch jobs.
 
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_patch_jobs():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListPatchJobsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_patch_jobs(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListPatchJobsRequest, dict]):
                 The request object. A request message for listing patch
@@ -411,7 +526,7 @@ class OsConfigServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -464,6 +579,24 @@ class OsConfigServiceAsyncClient:
     ) -> pagers.ListPatchJobInstanceDetailsAsyncPager:
         r"""Get a list of instance details for a given patch job.
 
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_patch_job_instance_details():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListPatchJobInstanceDetailsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_patch_job_instance_details(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsRequest, dict]):
                 The request object. Request to list details for all
@@ -491,7 +624,7 @@ class OsConfigServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -546,6 +679,26 @@ class OsConfigServiceAsyncClient:
     ) -> patch_deployments.PatchDeployment:
         r"""Create an OS Config patch deployment.
 
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_create_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.CreatePatchDeploymentRequest(
+                    parent="parent_value",
+                    patch_deployment_id="patch_deployment_id_value",
+                )
+
+                # Make the request
+                response = client.create_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.CreatePatchDeploymentRequest, dict]):
                 The request object. A request message for creating a
@@ -595,7 +748,7 @@ class OsConfigServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, patch_deployment, patch_deployment_id])
         if request is not None and has_flattened_params:
@@ -646,6 +799,25 @@ class OsConfigServiceAsyncClient:
     ) -> patch_deployments.PatchDeployment:
         r"""Get an OS Config patch deployment.
 
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetPatchDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetPatchDeploymentRequest, dict]):
                 The request object. A request message for retrieving a
@@ -674,7 +846,7 @@ class OsConfigServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -721,6 +893,24 @@ class OsConfigServiceAsyncClient:
     ) -> pagers.ListPatchDeploymentsAsyncPager:
         r"""Get a page of OS Config patch deployments.
 
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_patch_deployments():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListPatchDeploymentsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_patch_deployments(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListPatchDeploymentsRequest, dict]):
                 The request object. A request message for listing patch
@@ -748,7 +938,7 @@ class OsConfigServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -801,6 +991,22 @@ class OsConfigServiceAsyncClient:
     ) -> None:
         r"""Delete an OS Config patch deployment.
 
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_delete_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.DeletePatchDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.delete_patch_deployment(request=request)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.DeletePatchDeploymentRequest, dict]):
                 The request object. A request message for deleting a
@@ -819,7 +1025,7 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -854,6 +1060,306 @@ class OsConfigServiceAsyncClient:
             request, retry=retry, timeout=timeout, metadata=metadata,
         )
 
+    async def update_patch_deployment(
+        self,
+        request: Union[patch_deployments.UpdatePatchDeploymentRequest, dict] = None,
+        *,
+        patch_deployment: patch_deployments.PatchDeployment = None,
+        update_mask: field_mask_pb2.FieldMask = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> patch_deployments.PatchDeployment:
+        r"""Update an OS Config patch deployment.
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_update_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.UpdatePatchDeploymentRequest(
+                )
+
+                # Make the request
+                response = client.update_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1.types.UpdatePatchDeploymentRequest, dict]):
+                The request object. A request message for updating a
+                patch deployment.
+            patch_deployment (:class:`google.cloud.osconfig_v1.types.PatchDeployment`):
+                Required. The patch deployment to
+                Update.
+
+                This corresponds to the ``patch_deployment`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            update_mask (:class:`google.protobuf.field_mask_pb2.FieldMask`):
+                Optional. Field mask that controls
+                which fields of the patch deployment
+                should be updated.
+
+                This corresponds to the ``update_mask`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([patch_deployment, update_mask])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = patch_deployments.UpdatePatchDeploymentRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if patch_deployment is not None:
+            request.patch_deployment = patch_deployment
+        if update_mask is not None:
+            request.update_mask = update_mask
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.update_patch_deployment,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("patch_deployment.name", request.patch_deployment.name),)
+            ),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
+    async def pause_patch_deployment(
+        self,
+        request: Union[patch_deployments.PausePatchDeploymentRequest, dict] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> patch_deployments.PatchDeployment:
+        r"""Change state of patch deployment to "PAUSED".
+        Patch deployment in paused state doesn't generate patch
+        jobs.
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_pause_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.PausePatchDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.pause_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1.types.PausePatchDeploymentRequest, dict]):
+                The request object. A request message for pausing a
+                patch deployment.
+            name (:class:`str`):
+                Required. The resource name of the patch deployment in
+                the form ``projects/*/patchDeployments/*``.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = patch_deployments.PausePatchDeploymentRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.pause_patch_deployment,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
+    async def resume_patch_deployment(
+        self,
+        request: Union[patch_deployments.ResumePatchDeploymentRequest, dict] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> patch_deployments.PatchDeployment:
+        r"""Change state of patch deployment back to "ACTIVE".
+        Patch deployment in active state continues to generate
+        patch jobs.
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_resume_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ResumePatchDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.resume_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1.types.ResumePatchDeploymentRequest, dict]):
+                The request object. A request message for resuming a
+                patch deployment.
+            name (:class:`str`):
+                Required. The resource name of the patch deployment in
+                the form ``projects/*/patchDeployments/*``.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        request = patch_deployments.ResumePatchDeploymentRequest(request)
+
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if name is not None:
+            request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.resume_patch_deployment,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
     async def __aenter__(self):
         return self
 
