@@ -38,6 +38,7 @@ from google.cloud.osconfig_v1.services.os_config_service import pagers
 from google.cloud.osconfig_v1.types import patch_deployments
 from google.cloud.osconfig_v1.types import patch_jobs
 from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import OsConfigServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import OsConfigServiceGrpcTransport
@@ -270,6 +271,73 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -320,57 +388,22 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        if os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") not in (
-            "true",
-            "false",
-        ):
-            raise ValueError(
-                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
-            )
-        use_client_cert = (
-            os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") == "true"
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, OsConfigServiceTransport):
             # transport is a OsConfigServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -382,6 +415,15 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -405,6 +447,27 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Patch VM instances by creating and running a patch
         job.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_execute_patch_job():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ExecutePatchJobRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.execute_patch_job(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ExecutePatchJobRequest, dict]):
                 The request object. A request message to initiate
@@ -466,6 +529,27 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         progress of an ongoing patch job or review the details
         of completed jobs.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_patch_job():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetPatchJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_patch_job(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetPatchJobRequest, dict]):
                 The request object. Request to get an active or
@@ -498,7 +582,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -545,6 +629,27 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Cancel a patch job. The patch job must be active.
         Canceled patch jobs cannot be restarted.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_cancel_patch_job():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.CancelPatchJobRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.cancel_patch_job(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.CancelPatchJobRequest, dict]):
                 The request object. Message for canceling a patch job.
@@ -603,6 +708,25 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
     ) -> pagers.ListPatchJobsPager:
         r"""Get a list of patch jobs.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_patch_jobs():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListPatchJobsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_patch_jobs(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListPatchJobsRequest, dict]):
                 The request object. A request message for listing patch
@@ -628,7 +752,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -681,6 +805,25 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
     ) -> pagers.ListPatchJobInstanceDetailsPager:
         r"""Get a list of instance details for a given patch job.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_patch_job_instance_details():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListPatchJobInstanceDetailsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_patch_job_instance_details(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsRequest, dict]):
                 The request object. Request to list details for all
@@ -708,7 +851,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -765,6 +908,27 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
     ) -> patch_deployments.PatchDeployment:
         r"""Create an OS Config patch deployment.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_create_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.CreatePatchDeploymentRequest(
+                    parent="parent_value",
+                    patch_deployment_id="patch_deployment_id_value",
+                )
+
+                # Make the request
+                response = client.create_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.CreatePatchDeploymentRequest, dict]):
                 The request object. A request message for creating a
@@ -814,7 +978,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, patch_deployment, patch_deployment_id])
         if request is not None and has_flattened_params:
@@ -865,6 +1029,26 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
     ) -> patch_deployments.PatchDeployment:
         r"""Get an OS Config patch deployment.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetPatchDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetPatchDeploymentRequest, dict]):
                 The request object. A request message for retrieving a
@@ -893,7 +1077,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -940,6 +1124,25 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
     ) -> pagers.ListPatchDeploymentsPager:
         r"""Get a page of OS Config patch deployments.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_patch_deployments():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListPatchDeploymentsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_patch_deployments(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListPatchDeploymentsRequest, dict]):
                 The request object. A request message for listing patch
@@ -967,7 +1170,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1020,6 +1223,23 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
     ) -> None:
         r"""Delete an OS Config patch deployment.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_delete_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.DeletePatchDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.delete_patch_deployment(request=request)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.DeletePatchDeploymentRequest, dict]):
                 The request object. A request message for deleting a
@@ -1038,7 +1258,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1073,6 +1293,309 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
             request, retry=retry, timeout=timeout, metadata=metadata,
         )
 
+    def update_patch_deployment(
+        self,
+        request: Union[patch_deployments.UpdatePatchDeploymentRequest, dict] = None,
+        *,
+        patch_deployment: patch_deployments.PatchDeployment = None,
+        update_mask: field_mask_pb2.FieldMask = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> patch_deployments.PatchDeployment:
+        r"""Update an OS Config patch deployment.
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_update_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.UpdatePatchDeploymentRequest(
+                )
+
+                # Make the request
+                response = client.update_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1.types.UpdatePatchDeploymentRequest, dict]):
+                The request object. A request message for updating a
+                patch deployment.
+            patch_deployment (google.cloud.osconfig_v1.types.PatchDeployment):
+                Required. The patch deployment to
+                Update.
+
+                This corresponds to the ``patch_deployment`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            update_mask (google.protobuf.field_mask_pb2.FieldMask):
+                Optional. Field mask that controls
+                which fields of the patch deployment
+                should be updated.
+
+                This corresponds to the ``update_mask`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([patch_deployment, update_mask])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a patch_deployments.UpdatePatchDeploymentRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, patch_deployments.UpdatePatchDeploymentRequest):
+            request = patch_deployments.UpdatePatchDeploymentRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if patch_deployment is not None:
+                request.patch_deployment = patch_deployment
+            if update_mask is not None:
+                request.update_mask = update_mask
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.update_patch_deployment]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("patch_deployment.name", request.patch_deployment.name),)
+            ),
+        )
+
+        # Send the request.
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
+    def pause_patch_deployment(
+        self,
+        request: Union[patch_deployments.PausePatchDeploymentRequest, dict] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> patch_deployments.PatchDeployment:
+        r"""Change state of patch deployment to "PAUSED".
+        Patch deployment in paused state doesn't generate patch
+        jobs.
+
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_pause_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.PausePatchDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.pause_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1.types.PausePatchDeploymentRequest, dict]):
+                The request object. A request message for pausing a
+                patch deployment.
+            name (str):
+                Required. The resource name of the patch deployment in
+                the form ``projects/*/patchDeployments/*``.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a patch_deployments.PausePatchDeploymentRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, patch_deployments.PausePatchDeploymentRequest):
+            request = patch_deployments.PausePatchDeploymentRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if name is not None:
+                request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.pause_patch_deployment]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
+    def resume_patch_deployment(
+        self,
+        request: Union[patch_deployments.ResumePatchDeploymentRequest, dict] = None,
+        *,
+        name: str = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: float = None,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> patch_deployments.PatchDeployment:
+        r"""Change state of patch deployment back to "ACTIVE".
+        Patch deployment in active state continues to generate
+        patch jobs.
+
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_resume_patch_deployment():
+                # Create a client
+                client = osconfig_v1.OsConfigServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ResumePatchDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.resume_patch_deployment(request=request)
+
+                # Handle response
+                print(response)
+
+        Args:
+            request (Union[google.cloud.osconfig_v1.types.ResumePatchDeploymentRequest, dict]):
+                The request object. A request message for resuming a
+                patch deployment.
+            name (str):
+                Required. The resource name of the patch deployment in
+                the form ``projects/*/patchDeployments/*``.
+
+                This corresponds to the ``name`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
+
+        """
+        # Create or coerce a protobuf request object.
+        # Quick check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a patch_deployments.ResumePatchDeploymentRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, patch_deployments.ResumePatchDeploymentRequest):
+            request = patch_deployments.ResumePatchDeploymentRequest(request)
+            # If we have keyword arguments corresponding to fields on the
+            # request, apply these.
+            if name is not None:
+                request.name = name
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.resume_patch_deployment]
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+
+        # Done; return the response.
+        return response
+
     def __enter__(self):
         return self
 
