@@ -101,7 +101,6 @@ class OsConfigServiceTransport(abc.ABC):
             credentials, _ = google.auth.load_credentials_from_file(
                 credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
-
         elif credentials is None:
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
@@ -158,6 +157,21 @@ class OsConfigServiceTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.update_patch_deployment: gapic_v1.method.wrap_method(
+                self.update_patch_deployment,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.pause_patch_deployment: gapic_v1.method.wrap_method(
+                self.pause_patch_deployment,
+                default_timeout=None,
+                client_info=client_info,
+            ),
+            self.resume_patch_deployment: gapic_v1.method.wrap_method(
+                self.resume_patch_deployment,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -265,5 +279,41 @@ class OsConfigServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def update_patch_deployment(
+        self,
+    ) -> Callable[
+        [patch_deployments.UpdatePatchDeploymentRequest],
+        Union[
+            patch_deployments.PatchDeployment,
+            Awaitable[patch_deployments.PatchDeployment],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def pause_patch_deployment(
+        self,
+    ) -> Callable[
+        [patch_deployments.PausePatchDeploymentRequest],
+        Union[
+            patch_deployments.PatchDeployment,
+            Awaitable[patch_deployments.PatchDeployment],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def resume_patch_deployment(
+        self,
+    ) -> Callable[
+        [patch_deployments.ResumePatchDeploymentRequest],
+        Union[
+            patch_deployments.PatchDeployment,
+            Awaitable[patch_deployments.PatchDeployment],
+        ],
+    ]:
+        raise NotImplementedError()
+
 
 __all__ = ("OsConfigServiceTransport",)
