@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -145,6 +145,42 @@ class OsConfigZonalServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return OsConfigZonalServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> OsConfigZonalServiceTransport:
         """Returns the transport used by the client instance.
@@ -231,6 +267,38 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_create_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                os_policy_assignment = osconfig_v1.OSPolicyAssignment()
+                os_policy_assignment.os_policies.id = "id_value"
+                os_policy_assignment.os_policies.mode = "ENFORCEMENT"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.apt.name = "name_value"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.desired_state = "REMOVED"
+                os_policy_assignment.os_policies.resource_groups.resources.id = "id_value"
+                os_policy_assignment.rollout.disruption_budget.fixed = 528
+
+                request = osconfig_v1.CreateOSPolicyAssignmentRequest(
+                    parent="parent_value",
+                    os_policy_assignment=os_policy_assignment,
+                    os_policy_assignment_id="os_policy_assignment_id_value",
+                )
+
+                # Make the request
+                operation = client.create_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.CreateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to create an OS
@@ -289,7 +357,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [parent, os_policy_assignment, os_policy_assignment_id]
@@ -362,6 +430,36 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_update_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                os_policy_assignment = osconfig_v1.OSPolicyAssignment()
+                os_policy_assignment.os_policies.id = "id_value"
+                os_policy_assignment.os_policies.mode = "ENFORCEMENT"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.apt.name = "name_value"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.desired_state = "REMOVED"
+                os_policy_assignment.os_policies.resource_groups.resources.id = "id_value"
+                os_policy_assignment.rollout.disruption_budget.fixed = 528
+
+                request = osconfig_v1.UpdateOSPolicyAssignmentRequest(
+                    os_policy_assignment=os_policy_assignment,
+                )
+
+                # Make the request
+                operation = client.update_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.UpdateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to update an OS
@@ -406,7 +504,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([os_policy_assignment, update_mask])
         if request is not None and has_flattened_params:
@@ -469,6 +567,26 @@ class OsConfigZonalServiceAsyncClient:
         retrieve a previous revision of the assignment, also provide the
         revision ID in the ``name`` parameter.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetOSPolicyAssignmentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_os_policy_assignment(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to get an OS
@@ -505,7 +623,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -557,6 +675,25 @@ class OsConfigZonalServiceAsyncClient:
         For each OS policy assignment, the latest revision is
         returned.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_os_policy_assignments():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListOSPolicyAssignmentsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignments(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListOSPolicyAssignmentsRequest, dict]):
                 The request object. A request message to list OS policy
@@ -582,7 +719,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -638,6 +775,25 @@ class OsConfigZonalServiceAsyncClient:
         r"""List the OS policy assignment revisions for a given
         OS policy assignment.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_os_policy_assignment_revisions():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListOSPolicyAssignmentRevisionsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignment_revisions(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListOSPolicyAssignmentRevisionsRequest, dict]):
                 The request object. A request message to list revisions
@@ -665,7 +821,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -732,6 +888,28 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_delete_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.DeleteOSPolicyAssignmentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.DeleteOSPolicyAssignmentRequest, dict]):
                 The request object. A request message for deleting a OS
@@ -769,7 +947,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -827,6 +1005,26 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get the OS policy asssignment report for the
         specified Compute Engine VM instance.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_os_policy_assignment_report():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetOSPolicyAssignmentReportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_os_policy_assignment_report(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetOSPolicyAssignmentReportRequest, dict]):
                 The request object. Get a report of the OS policy
@@ -861,7 +1059,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -913,6 +1111,25 @@ class OsConfigZonalServiceAsyncClient:
         r"""List OS policy asssignment reports for all Compute
         Engine VM instances in the specified zone.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_os_policy_assignment_reports():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListOSPolicyAssignmentReportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignment_reports(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListOSPolicyAssignmentReportsRequest, dict]):
                 The request object. List the OS policy assignment
@@ -965,7 +1182,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1021,6 +1238,26 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get inventory data for the specified VM instance. If the VM has
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_inventory():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetInventoryRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_inventory(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetInventoryRequest, dict]):
                 The request object. A request message for getting
@@ -1060,7 +1297,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1108,6 +1345,25 @@ class OsConfigZonalServiceAsyncClient:
         r"""List inventory data for all VM instances in the
         specified zone.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_inventories():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListInventoriesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_inventories(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListInventoriesRequest, dict]):
                 The request object. A request message for listing
@@ -1141,7 +1397,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1196,6 +1452,26 @@ class OsConfigZonalServiceAsyncClient:
         instance. Only VMs with inventory data have
         vulnerability reports associated with them.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_vulnerability_report():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetVulnerabilityReportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_vulnerability_report(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetVulnerabilityReportRequest, dict]):
                 The request object. A request message for getting the
@@ -1231,7 +1507,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1279,6 +1555,25 @@ class OsConfigZonalServiceAsyncClient:
         r"""List vulnerability reports for all VM instances in
         the specified zone.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_vulnerability_reports():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListVulnerabilityReportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_vulnerability_reports(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListVulnerabilityReportsRequest, dict]):
                 The request object. A request message for listing
@@ -1313,7 +1608,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
