@@ -343,6 +343,73 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -393,57 +460,22 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        if os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") not in (
-            "true",
-            "false",
-        ):
-            raise ValueError(
-                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
-            )
-        use_client_cert = (
-            os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false") == "true"
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, OsConfigZonalServiceTransport):
             # transport is a OsConfigZonalServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -455,6 +487,15 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -492,6 +533,39 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_create_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                os_policy_assignment = osconfig_v1.OSPolicyAssignment()
+                os_policy_assignment.os_policies.id = "id_value"
+                os_policy_assignment.os_policies.mode = "ENFORCEMENT"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.apt.name = "name_value"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.desired_state = "REMOVED"
+                os_policy_assignment.os_policies.resource_groups.resources.id = "id_value"
+                os_policy_assignment.rollout.disruption_budget.fixed = 528
+
+                request = osconfig_v1.CreateOSPolicyAssignmentRequest(
+                    parent="parent_value",
+                    os_policy_assignment=os_policy_assignment,
+                    os_policy_assignment_id="os_policy_assignment_id_value",
+                )
+
+                # Make the request
+                operation = client.create_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.CreateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to create an OS
@@ -550,7 +624,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [parent, os_policy_assignment, os_policy_assignment_id]
@@ -627,6 +701,37 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_update_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                os_policy_assignment = osconfig_v1.OSPolicyAssignment()
+                os_policy_assignment.os_policies.id = "id_value"
+                os_policy_assignment.os_policies.mode = "ENFORCEMENT"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.apt.name = "name_value"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.desired_state = "REMOVED"
+                os_policy_assignment.os_policies.resource_groups.resources.id = "id_value"
+                os_policy_assignment.rollout.disruption_budget.fixed = 528
+
+                request = osconfig_v1.UpdateOSPolicyAssignmentRequest(
+                    os_policy_assignment=os_policy_assignment,
+                )
+
+                # Make the request
+                operation = client.update_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.UpdateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to update an OS
@@ -671,7 +776,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([os_policy_assignment, update_mask])
         if request is not None and has_flattened_params:
@@ -738,6 +843,27 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         retrieve a previous revision of the assignment, also provide the
         revision ID in the ``name`` parameter.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetOSPolicyAssignmentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_os_policy_assignment(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to get an OS
@@ -774,7 +900,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -826,6 +952,26 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For each OS policy assignment, the latest revision is
         returned.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_os_policy_assignments():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListOSPolicyAssignmentsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignments(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListOSPolicyAssignmentsRequest, dict]):
                 The request object. A request message to list OS policy
@@ -851,7 +997,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -911,6 +1057,26 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List the OS policy assignment revisions for a given
         OS policy assignment.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_os_policy_assignment_revisions():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListOSPolicyAssignmentRevisionsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignment_revisions(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListOSPolicyAssignmentRevisionsRequest, dict]):
                 The request object. A request message to list revisions
@@ -938,7 +1104,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1011,6 +1177,29 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_delete_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.DeleteOSPolicyAssignmentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.DeleteOSPolicyAssignmentRequest, dict]):
                 The request object. A request message for deleting a OS
@@ -1048,7 +1237,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1110,6 +1299,27 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""Get the OS policy asssignment report for the
         specified Compute Engine VM instance.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_os_policy_assignment_report():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetOSPolicyAssignmentReportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_os_policy_assignment_report(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetOSPolicyAssignmentReportRequest, dict]):
                 The request object. Get a report of the OS policy
@@ -1144,7 +1354,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1200,6 +1410,26 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List OS policy asssignment reports for all Compute
         Engine VM instances in the specified zone.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_os_policy_assignment_reports():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListOSPolicyAssignmentReportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignment_reports(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListOSPolicyAssignmentReportsRequest, dict]):
                 The request object. List the OS policy assignment
@@ -1252,7 +1482,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1312,6 +1542,27 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""Get inventory data for the specified VM instance. If the VM has
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_inventory():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetInventoryRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_inventory(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetInventoryRequest, dict]):
                 The request object. A request message for getting
@@ -1351,7 +1602,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1399,6 +1650,26 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List inventory data for all VM instances in the
         specified zone.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_inventories():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListInventoriesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_inventories(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListInventoriesRequest, dict]):
                 The request object. A request message for listing
@@ -1432,7 +1703,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1487,6 +1758,27 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         instance. Only VMs with inventory data have
         vulnerability reports associated with them.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_get_vulnerability_report():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.GetVulnerabilityReportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_vulnerability_report(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.GetVulnerabilityReportRequest, dict]):
                 The request object. A request message for getting the
@@ -1522,7 +1814,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1570,6 +1862,26 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         r"""List vulnerability reports for all VM instances in
         the specified zone.
 
+
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1
+
+            def sample_list_vulnerability_reports():
+                # Create a client
+                client = osconfig_v1.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1.ListVulnerabilityReportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_vulnerability_reports(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1.types.ListVulnerabilityReportsRequest, dict]):
                 The request object. A request message for listing
@@ -1604,7 +1916,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
