@@ -49,7 +49,10 @@ from .patch_deployments import (
     MonthlySchedule,
     OneTimeSchedule,
     PatchDeployment,
+    PausePatchDeploymentRequest,
     RecurringSchedule,
+    ResumePatchDeploymentRequest,
+    UpdatePatchDeploymentRequest,
     WeekDayOfMonth,
     WeeklySchedule,
 )
@@ -114,7 +117,10 @@ __all__ = (
     "MonthlySchedule",
     "OneTimeSchedule",
     "PatchDeployment",
+    "PausePatchDeploymentRequest",
     "RecurringSchedule",
+    "ResumePatchDeploymentRequest",
+    "UpdatePatchDeploymentRequest",
     "WeekDayOfMonth",
     "WeeklySchedule",
     "AptSettings",
