@@ -224,8 +224,7 @@ class Inventory(proto.Message):
             qfe_package (google.cloud.osconfig_v1.types.Inventory.WindowsQuickFixEngineeringPackage):
                 Details of a Windows Quick Fix engineering
                 package. See
-                https://docs.microsoft.com/en-
-                us/windows/win32/cimwin32prov/win32-quickfixengineering
+                https://docs.microsoft.com/en-us/windows/win32/cimwin32prov/win32-quickfixengineering
                 for info in Windows Quick Fix Engineering.
 
                 This field is a member of `oneof`_ ``details``.
@@ -400,8 +399,7 @@ class Inventory(proto.Message):
         r"""Information related to a Quick Fix Engineering package.
         Fields are taken from Windows QuickFixEngineering Interface and
         match the source names:
-        https://docs.microsoft.com/en-
-        us/windows/win32/cimwin32prov/win32-quickfixengineering
+        https://docs.microsoft.com/en-us/windows/win32/cimwin32prov/win32-quickfixengineering
 
         Attributes:
             caption (str):
@@ -425,12 +423,10 @@ class Inventory(proto.Message):
         )
 
     class WindowsApplication(proto.Message):
-        r"""Contains information about a Windows application as retrieved from
-        the Windows Registry. For more information about these fields, see
-
-        `Windows Installer Properties for the Uninstall
-        Registry <https://docs.microsoft.com/en-us/windows/win32/msi/uninstall-registry-key>`__\ {:
-        class="external" }
+        r"""Contains information about a Windows application that is
+        retrieved from the Windows Registry. For more information about
+        these fields, see:
+        https://docs.microsoft.com/en-us/windows/win32/msi/uninstall-registry-key
 
         Attributes:
             display_name (str):
