@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -140,6 +140,42 @@ class OsConfigZonalServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return OsConfigZonalServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> OsConfigZonalServiceTransport:
         """Returns the transport used by the client instance.
@@ -226,6 +262,38 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_create_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                os_policy_assignment = osconfig_v1alpha.OSPolicyAssignment()
+                os_policy_assignment.os_policies.id = "id_value"
+                os_policy_assignment.os_policies.mode = "ENFORCEMENT"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.apt.name = "name_value"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.desired_state = "REMOVED"
+                os_policy_assignment.os_policies.resource_groups.resources.id = "id_value"
+                os_policy_assignment.rollout.disruption_budget.fixed = 528
+
+                request = osconfig_v1alpha.CreateOSPolicyAssignmentRequest(
+                    parent="parent_value",
+                    os_policy_assignment=os_policy_assignment,
+                    os_policy_assignment_id="os_policy_assignment_id_value",
+                )
+
+                # Make the request
+                operation = client.create_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.CreateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to create an OS
@@ -284,7 +352,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [parent, os_policy_assignment, os_policy_assignment_id]
@@ -357,6 +425,36 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_update_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                os_policy_assignment = osconfig_v1alpha.OSPolicyAssignment()
+                os_policy_assignment.os_policies.id = "id_value"
+                os_policy_assignment.os_policies.mode = "ENFORCEMENT"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.apt.name = "name_value"
+                os_policy_assignment.os_policies.resource_groups.resources.pkg.desired_state = "REMOVED"
+                os_policy_assignment.os_policies.resource_groups.resources.id = "id_value"
+                os_policy_assignment.rollout.disruption_budget.fixed = 528
+
+                request = osconfig_v1alpha.UpdateOSPolicyAssignmentRequest(
+                    os_policy_assignment=os_policy_assignment,
+                )
+
+                # Make the request
+                operation = client.update_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.UpdateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to update an OS
@@ -401,7 +499,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([os_policy_assignment, update_mask])
         if request is not None and has_flattened_params:
@@ -464,6 +562,26 @@ class OsConfigZonalServiceAsyncClient:
         retrieve a previous revision of the assignment, also provide the
         revision ID in the ``name`` parameter.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_get_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.GetOSPolicyAssignmentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_os_policy_assignment(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to get an OS
@@ -500,7 +618,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -552,6 +670,25 @@ class OsConfigZonalServiceAsyncClient:
         For each OS policy assignment, the latest revision is
         returned.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_list_os_policy_assignments():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.ListOSPolicyAssignmentsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignments(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentsRequest, dict]):
                 The request object. A request message to list OS policy
@@ -577,7 +714,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -633,6 +770,25 @@ class OsConfigZonalServiceAsyncClient:
         r"""List the OS policy assignment revisions for a given
         OS policy assignment.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_list_os_policy_assignment_revisions():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.ListOSPolicyAssignmentRevisionsRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                page_result = client.list_os_policy_assignment_revisions(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentRevisionsRequest, dict]):
                 The request object. A request message to list revisions
@@ -660,7 +816,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -727,6 +883,28 @@ class OsConfigZonalServiceAsyncClient:
         For more information, see `Method:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_delete_os_policy_assignment():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.DeleteOSPolicyAssignmentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_os_policy_assignment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.DeleteOSPolicyAssignmentRequest, dict]):
                 The request object. A request message for deleting a OS
@@ -764,7 +942,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -822,6 +1000,26 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get OS policies compliance data for the specified
         Compute Engine VM instance.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_get_instance_os_policies_compliance():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.GetInstanceOSPoliciesComplianceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_instance_os_policies_compliance(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.GetInstanceOSPoliciesComplianceRequest, dict]):
                 The request object. A request message for getting OS
@@ -868,7 +1066,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -921,6 +1119,25 @@ class OsConfigZonalServiceAsyncClient:
         r"""List OS policies compliance data for all Compute
         Engine VM instances in the specified zone.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_list_instance_os_policies_compliances():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.ListInstanceOSPoliciesCompliancesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_instance_os_policies_compliances(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.ListInstanceOSPoliciesCompliancesRequest, dict]):
                 The request object. A request message for listing OS
@@ -954,7 +1171,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1010,6 +1227,26 @@ class OsConfigZonalServiceAsyncClient:
         r"""Get inventory data for the specified VM instance. If the VM has
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_get_inventory():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.GetInventoryRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_inventory(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.GetInventoryRequest, dict]):
                 The request object. A request message for getting
@@ -1049,7 +1286,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1097,6 +1334,25 @@ class OsConfigZonalServiceAsyncClient:
         r"""List inventory data for all VM instances in the
         specified zone.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_list_inventories():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.ListInventoriesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_inventories(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.ListInventoriesRequest, dict]):
                 The request object. A request message for listing
@@ -1132,7 +1388,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -1187,6 +1443,26 @@ class OsConfigZonalServiceAsyncClient:
         instance. Only VMs with inventory data have
         vulnerability reports associated with them.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_get_vulnerability_report():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.GetVulnerabilityReportRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_vulnerability_report(request=request)
+
+                # Handle response
+                print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.GetVulnerabilityReportRequest, dict]):
                 The request object. A request message for getting the
@@ -1222,7 +1498,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1270,6 +1546,25 @@ class OsConfigZonalServiceAsyncClient:
         r"""List vulnerability reports for all VM instances in
         the specified zone.
 
+
+        .. code-block::
+
+            from google.cloud import osconfig_v1alpha
+
+            def sample_list_vulnerability_reports():
+                # Create a client
+                client = osconfig_v1alpha.OsConfigZonalServiceClient()
+
+                # Initialize request argument(s)
+                request = osconfig_v1alpha.ListVulnerabilityReportsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_vulnerability_reports(request=request)
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.osconfig_v1alpha.types.ListVulnerabilityReportsRequest, dict]):
                 The request object. A request message for listing
@@ -1306,7 +1601,7 @@ class OsConfigZonalServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
