@@ -231,20 +231,18 @@ class ListVulnerabilityReportsResponse(proto.Message):
 
 class CVSSv3(proto.Message):
     r"""Common Vulnerability Scoring System version 3.
-    For details, see https://www.first.org/cvss/specification-
-    document
+    For details, see
+    https://www.first.org/cvss/specification-document
 
     Attributes:
         base_score (float):
             The base score is a function of the base
             metric scores.
-            https://www.first.org/cvss/specification-
-            document#Base-Metrics
+            https://www.first.org/cvss/specification-document#Base-Metrics
         exploitability_score (float):
             The Exploitability sub-score equation is
             derived from the Base Exploitability metrics.
-            https://www.first.org/cvss/specification-
-            document#2-1-Exploitability-Metrics
+            https://www.first.org/cvss/specification-document#2-1-Exploitability-Metrics
         impact_score (float):
             The Impact sub-score equation is derived from
             the Base Impact metrics.
